@@ -45,7 +45,10 @@ data ConfigData = ConfigData {
   , _promptsDirConfigData :: FilePath
   , _resourcesDirConfigData :: FilePath
   , _workDirConfigData :: Maybe FilePath
+  , _sandboxDirConfigData :: Maybe FilePath
   , _promptsConfigData :: [String]
+  , _invalidCharsConfigData :: [String]
+  , _invalidCmdsConfigData :: [String]
   } deriving (Show, Read, Eq)
 
 makeLenses ''ConfigData
@@ -63,6 +66,7 @@ instance Default ConfigData where
       , _promptsDirConfigData = "pty-mcp-server/prompts"
       , _resourcesDirConfigData = "pty-mcp-server/resources"
       , _workDirConfigData = def
+      , _sandboxDirConfigData = def
       , _promptsConfigData = [
           ">>>"
         , "]#"
@@ -72,6 +76,22 @@ instance Default ConfigData where
         , "password:"
         , "ghci>"
         ]
+      , _invalidCharsConfigData = [
+          "&&"
+        , "||"
+        , "|"
+        , ".."
+        , "reboot"
+        , "shutdown"
+        , "restart"
+        , "kill"
+        ]
+      , _invalidCmdsConfigData = [
+          "del", "erase", "rd", "rmdir", "format"
+        , "shutdown", "restart", "taskkill"
+        , "rm", "mv", "dd", "chmod", "chown"
+        , "reboot", "kill", "nc", "sudo", "su"
+        ]
       }
 
 
